@@ -3,18 +3,7 @@
 BoundingBox::BoundingBox(){}
 BoundingBox::BoundingBox(const Point center, const Point half_res) : center(center), half_res(half_res) {}
 
-bool BoundingBox::contains(const Point& p)
-{
-  if(p.x >= center.x - half_res.x &&
-     p.x <= center.x + half_res.x &&
-     p.y >= center.y - half_res.y &&
-     p.y <= center.y + half_res.y)
-    return true;
-  else
-    return false;
-}
-
-bool BoundingBox::contains(const Point& p, double buffer)
+bool BoundingBox::contains(const Point& p, double buffer = 0)
 {
   if(p.x >= center.x - half_res.x - buffer &&
      p.x <= center.x + half_res.x + buffer &&
