@@ -1,7 +1,7 @@
 context("tree_detection")
 
 LASfile <- system.file("extdata", "MixedConifer.laz", package="lidR")
-las = readLAS(LASfile, select = "xyz", filter = "-drop_z_below 0")
+las = readLAS(LASfile, select = "xyzt", filter = "-drop_z_below 0")
 ctg = catalog(LASfile)
 
 opt_progress(ctg) <- FALSE
@@ -14,6 +14,7 @@ test_that("tree_detection LMF works with a LAS", {
   ttops = tree_detection(las, lmf(5))
 
   expect_is(ttops, "SpatialPointsDataFrame")
+  expect_true(is.integer(ttops$treeID))
   expect_equal(dim(ttops@data), c(177,2))
   expect_equal(ttops@proj4string, las@proj4string)
 
@@ -21,6 +22,7 @@ test_that("tree_detection LMF works with a LAS", {
   ttops = tree_detection(las, lmf(f))
 
   expect_is(ttops, "SpatialPointsDataFrame")
+  expect_true(is.integer(ttops$treeID))
   expect_equal(dim(ttops@data), c(205,2))
   expect_equal(ttops@proj4string, las@proj4string)
 })
@@ -40,6 +42,7 @@ test_that("tree_detection LMF works with a RasterLayer", {
   ttops = tree_detection(chm, lmf(f))
 
   expect_is(ttops, "SpatialPointsDataFrame")
+  expect_true(is.integer(ttops$treeID))
   expect_equal(dim(ttops@data), c(186,2))
   expect_equal(ttops@proj4string, chm@crs)
 })
@@ -49,10 +52,25 @@ test_that("tree_detection LMF works with a LAScatalog", {
   ttops = tree_detection(ctg, lmf(5))
 
   expect_is(ttops, "SpatialPointsDataFrame")
+  expect_true(is.integer(ttops$treeID))
   expect_equal(dim(ttops@data), c(177,2))
   expect_equal(ttops@proj4string, ctg@proj4string)
 })
 
+test_that("find_trees supports different unicity strategies", {
+
+  ttops = find_trees(las, lmf(5), uniqueness = "gpstime")
+
+  expect_true(is.double(ttops$treeID))
+  expect_equal(mean(ttops$treeID), 151436.2, tol = 0.01)
+
+  ttops = find_trees(las, lmf(5), uniqueness = "bitmerge")
+
+  expect_true(is.double(ttops$treeID))
+  expect_equal(mean(ttops$treeID), 206718581340247136)
+})
+
+
 test_that("Special test for R-devel with gcc8", {
 
   layout <- lidR:::rOverlay(las, 1, buffer = 0.15)
